"""Test the Django DataDog integration.
"""
try:
    from unittest import TestCase, main, mock
except ImportError:
    import mock
    from unittest import TestCase, main

from django.conf import settings
from django.test import override_settings

from django_datadog.compat import create_event, create_gauge


NOT_CONFIGURED = {'DATADOG': {'ENABLED': False}}
CONFIGURED = {'DATADOG': {'ENABLED': True,
                          'API_KEY': 'test',
                          'APP_KEY': 'test'},
              'STATSD_HOST': 'localhost',
              'STATSD_PORT': '12334'}

settings.configure()


@mock.patch('django_datadog.compat.api')
class EventTestCase(TestCase):
    """Test DataDog events.
    """

    @override_settings(**NOT_CONFIGURED)
    def test_not_configured(self, api):
        """Do not send events if not configured.
        """
        create_event('test_event', fmt_text='Extended text')
        self.assertFalse(api.Event.create.called)

    @override_settings(**CONFIGURED)
    def test_configured(self, api):
        """Send an event if configured.
        """
        create_event('test_event', fmt_text='Extended text')
        self.assertTrue(api.Event.create.called)

        api.Event.create.assert_called_with(alert_level='info',
                                            priority='low',
                                            text='Extended text',
                                            title='test_event')

    @override_settings(**CONFIGURED)
    def test_format_text(self, api):
        """Send formatted text.
        """
        create_event('test_event', fmt_text='Extended text: %s',
                     text_args=('Value',))
        self.assertTrue(api.Event.create.called)

        api.Event.create.assert_called_with(alert_level='info',
                                            priority='low',
                                            text='Extended text: Value',
                                            title='test_event')


@mock.patch('django_datadog.compat.statsd')
class GaugeTestCase(TestCase):
    """Test DataDog Gauges.
    """

    @override_settings(**NOT_CONFIGURED)
    def test_not_configured(self, statsd):
        """Do not send events if not configured.
        """
        create_gauge('some_gauge', value=10)
        self.assertFalse(statsd.gauge.called)

    @override_settings(**CONFIGURED)
    def test_configured(self, statsd):
        """Send an event if configured.
        """
        create_gauge('some_gauge', value=10)
        self.assertTrue(statsd.gauge.called)

        statsd.gauge.assert_called_with(metric='some_gauge', value=10,
                                        tags=None, sample_rate=1)


if __name__ == '__main__':
    main()



from datadog import initialize

from django.conf import settings


def init_datadog():
    """Initialise DataDog for stats gathering.

    :returns: bool
    """
    if settings.DATADOG['ENABLED']:
        initialize(statsd_host=settings.STATSD_HOST,
                   statsd_port=settings.STATSD_PORT,
                   api_key=settings.DATADOG['API_KEY'],
                   app_key=settings.DATADOG['APP_KEY'])
        return True

    return False



"""Compatibility functions for DataDog integrations.
"""
from __future__ import absolute_import, print_function, unicode_literals

import logging
import six

from datadog import api, statsd
from requests.exceptions import HTTPError

from .utils import init_datadog

logger = logging.getLogger(__name__)


def create_event(title, fmt_text, priority='low', text_args=(),
                 alert_level='info', **kwargs):
    """Create a DataDog Event.

    :type title: str
    :param title: The event title for DataDog.

    :type fmt_text: str
    :param fmt_text: The pre-formatted text string. Send in the format string
    and text args for logging. This must be % formatted.

    :type aggregation_key: str
    :param aggregation_key: Aggregate results on DataDog

    :type priority: str
    :param priority: "low", "normal"

    :type text_args: tuple
    :param text_args: The tuple of text args for fmt_text

    :type alert_level: str
    :param alert_level: "error", "warning", "info", or "success"
    """
    if init_datadog():
        try:
            create_kwargs = {
                'title': title,
                'text': fmt_text % text_args,
                'priority': priority,
                'alert_level': alert_level,
            }
            create_kwargs.update(kwargs)
            api.Event.create(**create_kwargs)
        except HTTPError as exc:
            logger.error('Error occurred connecting to DataDog: %s',
                         six.text_type(exc))
            logger.log(alert_level, fmt_text, *text_args)
        except Exception as exc:
            logger.error('An unknown error occurred in event: %s',
                         six.text_type(exc))
    else:
        logger.log(loglevel(alert_level), fmt_text, *text_args)


def create_gauge(title, value, tags=None, sample_rate=1):
    """Create a statsd gauge event for DataDog.

    :type title: str
    :param title: The metric to track

    :type value: numeric
    :param value: The value of the metric

    :type tags: list
    :param tags: The tags to attach to the metric for analysis

    :type sample_rate: int
    :param sample_rate:
    """
    if init_datadog():
        try:
            statsd.gauge(metric=title, value=value, tags=tags,
                         sample_rate=sample_rate)
        except HTTPError as exc:
            logger.error('DataDog returned error calling statsd %s',
                         six.text_type(exc))
        except Exception as exc:
            logger.error('An unknown error occurred in gauge: %s',
                         six.text_type(exc))
    else:
        log_msg = '{}: %d'.format(title)
        logger.info(log_msg, value)
        
        
def create_increment(metric, **kwargs):
    """Create a statsd increment event for DataDog.

    :type metric: str
    :param metric: The metric to increment
    """
    if init_datadog():
        try:
            statsd.increment(metric, **kwargs)
        except HTTPError as exc:
            logger.error('DataDog returned error calling statsd %s',
                         six.text_type(exc))
        except Exception as exc:
            logger.error('An unknown error occurred in gauge: %s',
                         six.text_type(exc))
    else:
        log_msg = '{}: %d'.format(metric)
        logger.info(log_msg)


def loglevel(log_level):
    """Return the log-level for the logging module.

    :type log_level: str
    :param log_level: The log-level string

    :returns: int
    """
    levels = {
        'info': logging.INFO,
        'error': logging.ERROR,
        'warning': logging.WARNING,
        'success': logging.INFO,
    }
    return levels[log_level]



"""Setup.py.
"""
from os import path
from setuptools import setup, find_packages


CLASSIFIERS = [
    'Development Status :: 5 - Production/Stable',
    'Intended Audience :: Developers',
    'License :: OSI Approved :: MIT License',
    'Operating System :: OS Independent',
    'Programming Language :: Python',
    'Programming Language :: Python :: 2.7',
    'Programming Language :: Python :: 3.5',
    'Topic :: Software Development :: Libraries :: Python Modules',
    'Framework :: Django',
]

README_FILE = path.join(path.dirname(path.abspath(__file__)), 'README.md')

try:
    import m2r
    LONG_DESCRIPTION = m2r.parse_from_file(README_FILE)
except Exception:
    LONG_DESCRIPTION = ''

setup(
    name='django-datadog-compatibility',
    version='0.0.3',
    description="A simple DataDog Integration for Django",
    author="SF Software limited t/a Pebble",
    author_email="sysadmin@mypebble.co.uk",
    url="https://github.com/mypebble/django-datadog",
    packages=find_packages(),
    include_package_data=True,
    zip_safe=False,
    license='MIT',
    install_requires=['six', 'datadog', 'django'],
    classifiers=CLASSIFIERS,
    long_description=LONG_DESCRIPTION,
    test_suite='django_datadog.tests',
)
